Bifrost: src/DataAccessor.hpp File Reference

Bifrost

Data Structures
DataAccessor.hpp File Reference

Interface for the class DataAccessor. More...

Go to the source code of this file.

## Data Structures
class | DataAccessor< Unitig_data_t >
| Interface to access the colors and the data associated with a unitig of a ColoredCDBG. More...

## Detailed Description

Interface for the class DataAccessor.

The purpose of a DataAccessor object is to provide access to the colors and the data associated with a unitig of a ColoredCDBG. Code snippets using this interface are provided in snippets/test.cpp.